@@ -38,16 +38,7 @@ Example:
     ...                                labels=['Experiment A', 'Experiment B'])
 """
 
-# Read version from VERSION file (single source of truth)
-try:
-    from pathlib import Path
-    _version_file = Path(__file__).parent.parent / "VERSION"
-    if _version_file.exists():
-        __version__ = _version_file.read_text().strip()
-    else:
-        __version__ = "0.1.0"
-except Exception:
-    __version__ = "0.1.0"
+__version__ = "0.2.1"
 __author__ = "Featrix"
 __email__ = "support@featrix.com"
 __license__ = "MIT"
